changeset 2598:95d96304f4f1

Added tsta to GetSect routine. RG
author robertgault
date Fri, 30 Dec 2011 03:11:49 +0000
parents 62355a3b98ff
children 67f9b769969f
files 3rdparty/drivers/emudsk/emudsk.asm
diffstat 1 files changed, 4 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/3rdparty/drivers/emudsk/emudsk.asm	Wed Dec 28 13:23:16 2011 +0000
+++ b/3rdparty/drivers/emudsk/emudsk.asm	Fri Dec 30 03:11:49 2011 +0000
@@ -12,7 +12,8 @@
 *        Note the forced > extended addressing in some cases.
 *        That is required as this code is relocatable but the
 *        addresses are fixed. Part of original code.
 *  03    Corrected minor errors in GETSTAT.        R. Gault 11/12/26
 
 * EmuDisk floppy disk controller driver
 * Edition #1
@@ -73,7 +74,6 @@
 rev      set   $02
 
          mod   eom,name,tylg,atrv,start,size
-         fcb   $ff
 
          org   0
 u0000    rmb   DRVBEG+(DRVMEM*2) Normal RBF device mem for 2 drives RG
@@ -82,7 +82,7 @@
 
          fcb   $FF            This byte is the driver permissions
 name     fcs   /EmuDsk/
-         fcb   3              edition #2 RG
+         fcb   4              edition #4 RG
 
 
 * Entry: Y=Ptr to device descriptor
@@ -165,6 +165,7 @@
          sta   >command       get the emulator to blast over the sector
          lda   >command       get the error status
          clr   >vhdnum
+         tsta
          bne   FixErr         if non-zero, go report the error and exit
          puls  b,x,pc         restore registers and exit
@@ -12,7 +12,8 @@
 *        That is required as this code is relocatable but the
 *        addresses are fixed. Part of original code.
-*  03    Corrected minor errors in GETSTAT.        R. Gault 11/12/26
+*  03    Corrected minor errors in GetSect.        R. Gault 11/12/26
+*  04    Added a tsta I left out in GetSect.       R. Gault 11/12/29
 
 * EmuDisk floppy disk controller driver